@@ -27,6 +27,8 @@ import opsramp.monitoring
 import opsramp.msp
 import opsramp.devmgmt
 import opsramp.integrations
+import opsramp.roles
+import opsramp.escalations
 
 
 class Tenant(ApiWrapper):
@@ -63,3 +65,9 @@ class Tenant(ApiWrapper):
 
     def credential_sets(self):
         return opsramp.devmgmt.CredentialSets(self)
+
+    def roles(self):
+        return opsramp.roles.Roles(self)
+
+    def escalations(self):
+        return opsramp.escalations.Escalations(self)
